@@ -16,7 +16,22 @@ sub sshd_cmd {
 
     for my $sshd (@paths) {
 	return $sshd if -x $sshd;
-    }    
+    }
+}
+
+sub find_cmd {
+    my @path = qw(/usr/bin /bin
+		  /usr/local/bin
+		  /usr/sbin /sbin
+		  /opt/bin );
+
+    for my $cmd (@_) {
+	for my $path (@path) {
+	    my $r = "$path/$cmd";
+	    return $r if -x $r;
+	}
+    }
+    undef;
 }
 
 1;
